intervaltreetools.calculate_sustain_centroid_of_intervals
=========================================================

.. autofunction:: abjad.tools.intervaltreetools.calculate_sustain_centroid_of_intervals
